# CSES Helper functions

This package provides utility functions for solving cses problems.

While solving CSES problems, often times we would need the same functions. This package aims to provide helper
functions to address the problem.

## Installation

```
pip install cses-aid
```

## Usage

```
from cses-aid import prefix_sums, sieve

print(sieve(100)) # print the first 100 prime numbers

```

## Contribution

    Refer to CONTRIBUTING.md for all the information

## Contact
Please create an issue or hit me up if you spot an improvement! <br>

[Email](shlok.kothari@gmail.com) - shlok.kothari@gmail.com